@@ -140,8 +140,8 @@ class GuiMyTube:
 
     def cb_deleteStored(self, widget, data=None):
         print "deleting stored",
-        import ui.confirm
-        if not ui.confirm.showDialog("Delete"):
+        import mytube.ui.confirm as confirm
+        if not confirm.showDialog("Delete"):
             print "you should be sure!"
             return
         yentry, idx = self.getSelectedVideo()
